@@ -7,7 +7,7 @@ use utf8;
 use experimental qw(switch);
 
 # Don't forget to change the version in the pod
-our $VERSION = v1.3.1;
+our $VERSION = v1.3.2;
 
 use File::Spec;
 use Mustache::Simple::ContextStack v1.3.1;
@@ -29,7 +29,7 @@ See L<http://mustache.github.com/>.
 
 =head1 VERSION
 
-This document describes Mustache::Simple version 1.3.0
+This document describes Mustache::Simple version 1.3.2
 
 =head1 SYNOPSIS
 
@@ -374,6 +374,7 @@ sub resolve
                 }
                 else {
                     $txt = $self->find($tag->{txt});    # get the entry from the context
+                    $txt = &$txt if ref $txt eq 'CODE';
                 }
                 given (reftype $txt)
                 {
@@ -428,6 +429,9 @@ sub resolve
                     when ('HASH') {
                         $ans = $self->resolve(undef, @subtags) if keys %$txt == 0;
                     }
+                    when ('CODE') {
+                        $ans = $self->resolve(undef, @subtags) unless &$txt;
+                    }
                     default {
                         $ans = $self->resolve(undef, @subtags) unless $txt;
                     }
